@@ -2,4 +2,4 @@
 # -*- coding: utf-8 -*-
 
 # imports.
-from netw0rk.v1 import *
+from netw0rk.classes import *
